#!/usr/bin/python3

import pytest
from clmctest.monitoring.StreamingSim import reportMC_ServiceState

class TestMediaComponentConfig( object ):
    """
    Test class to check the reported output of a media component's configuration test
    as it is reported to the CLMC
    """

    # For data sent to INFLUX, see reportMC_ServiceState function in StreamingSim.py

    @pytest.mark.parametrize( "query, expectedResult", [
        ('SELECT "serviceStopped", "avgServiceStopped", "serviceStarted", "avgServiceStarted" FROM "CLMCMetrics"."autogen"."mediaComponentConfig" WHERE ipendpoint=\'adaptive_streaming_I1_apache1\'',
        {"time" : "1970-01-01T00:00:00Z", "serviceStopped" : 1500, "avgServiceStopped" : 750, "serviceStarted" : 8500, "avgServiceStarted" : 4250}),
        ('SELECT "serviceStopped", "avgServiceStopped", "serviceStarted", "avgServiceStarted" FROM "CLMCMetrics"."autogen"."mediaComponentConfig" WHERE ipendpoint=\'adaptive_streaming_I1_apache2\'',
        {"time" : "1970-01-01T00:00:00Z", "serviceStopped" : 250, "avgServiceStopped" : 250, "serviceStarted" : 9500, "avgServiceStarted" : 4750})
    ])

    def test_serviceStateReport( self, query, expectedResult, get_db_client, reportMC_ServiceState ):
        """
        :param query: the LineProtocol query to search for MC service state report
        :param expectedResult: the JSON result obtained from the query
        :param get_db_client: fixture from conftest.py returning INFLUX query client
        :param reportMC_ServiceState: the fixture that makes the service state report
        """
        print( "\n" ) # White space for output

        # Query for result and report problems with query if necessary
        queryResult = get_db_client.query( query, raise_errors = False )
        assert queryResult.error is None, "An error occurred executing query {0}."

        # Get result and evaluate
        actualResult = next( queryResult.get_points() )

        assert expectedResult == actualResult, "FAIL" #self.outputComparison( expectedResult, actualResult )
        print ("Media Component service state test succeeded: {0}".format( query ))
